# Moss species and precipitation mediate experimental warming stimulation of growing season N2 fixation in subarctic tundra

[https://doi.org/10.5061/dryad.6wwpzgn6m](https://doi.org/10.5061/dryad.6wwpzgn6m)

## Description of the data and file structure

R scripts and data were used to investigate the effect of experimental field warming and mean annual precipitation on N fixation in 3 moss species in subarctic Sweden. Various supporting data include daily values of soil temperature and moisture in the experimental plots, measured rainfall at site level along precipitation gradient, moss shoot d13C, and density. Also data for converting acetylene reduction to N2 fixation. 

Data and units are in .rds format, which is readily read by the two provided R scripts. Across data sets variables are:

site: 8 sites in the Tornetrask area, Northern Sweden
prec_int: Site precipitation, mm y-1. Gridded data of climate normals 1961-1991.
otc: warming treatment with open-top chamber (W) or controls (C)
moss: moss species, *Hylocomium splendens* (H), *Pleurozium schreberi* (P), *Sphagnum* ssp. (S)
serie: measurement round (A-E) during growing season 2018
serie_date: date interval for each measurement round
doy: day of the year of measurement
date: date of measurement

### **List of files and additional descriptions of variables:** 

**ethylene_chamber_field_long.rds** – ethylene production after Acetylene Reduction Assays on 48 moss cores during 5 field campaigns and under standardized conditions at 7 C.

serie: date interval for each measurement round, 'clim' refers to climate chamber measurements at 7C

**ARA_15N_conversion.rds** – climate chamber ethylene production and 15N uptake in thr 48 moss cores.

etylen_korr_um_pr_hr_m2: ethylene production, microgram per hour per square meter
top_N_uptake_um_m2_hr: calculated N fixation in 0-2 cm moss + brown moss, microgram N per hour per square meter
top_15N_uptake_um_m2_hr:  15N uptake in 0-2 cm moss + brown moss, microgram 15N per hour per square meter
soil_15N_uptake_um_m2_hr: 15N uptake in the soil layer, microgram per hour 15N per square meter

**moss_15Nuptake.rds** – the uptake of 15N in each fraction of moss cores which were incubated in 15N2 gas after the field season. 

fraction moss: top 2 cm (top_0_2), brown layer under 2 cm (brown_u2 soil), non-target moss and lichens (other), top 1 cm(top_0_1), 1-2 cm  (top_1_2)
ug15N_pr_gDW: 15N content of dry weight biomass, mikro g g-1
DW_g: Dry weight of fraction, g

**N2_ARA_d13C_density_incubation_T_moist.rds** – data for N2 fixation, incubation conditions during field sampling, and final d13C and biomass in green parts of moss shoots in the 48 moss cores.

Tmean: incubation temperature, C 
watercontent_g_pr_g_bm: moss core moisture content during incubation
etylen_korr_um_pr_hr_m2: ethylene production, microgram per hour per square meter 
N_um_hr_m2: calculated N fixation, microgram per hour per square meter
d13C_toplayer: delta 13 C in moss shoots (upper 2 cm for H and P and upper 1 cm for *Sphagnum*)
density_toplayer: density, g cm-3 in moss shoots (upper 2 cm for H and P and upper 1 cm for *Sphagnum*)

 **HOBO_raingauges.rds** – Data summarizing total precipitation and number of days with at least one rain event in the period 25 June – 20 September 2014 at the eight sites along the mean annual precipitation gradient.

event_days: No of days with precipitation
MAP: Mean annual precipitation,  Site precipitation, mm y-1. Gridded data of climate normals 1961-1991. 

 **VWC_temp_wm_daily.rds** – Data summarizing daily mean, max, and min of hourly logged soil temperature and volumetric moisture content in all 48 experimental plots during the study period (2018). sensor placed in - 5cm of moss mat. Missing values occur.
place: 4 places including two sites each; jiepren = jiepren1 + jiperen2, palno = palno1 + palno2, paddus = paddus1 + paddus2, katter = katter + vassi
VWC_day_mean: daily mean of hourly measurements, Volumetric water content, cm^3/cm^3
VWC_day_min: daily minimum of hourly measurements, Volumetric water content, cm^3/cm^3
VWC_day_max: daily maximum of hourly measurements, Volumetric water content, cm^3/cm^3
Temp_day_mean: daily mean of hourly measurements, temperature, C
Temp_day_min: daily minimum of hourly measurements, temperature, C
Temp_day_max: daily maximum of hourly measurements, temperature, C
Moss_moisture_g_g_mean: daily mean of hourly measurements, gravimetric moisture content, cm^3/cm^3
Moss_moisture_g_g_min: daily min of hourly measurements, moisture content, cm^3/cm^3
Moss_moisture_g_g_max: daily max of hourly measurements, moisture content, cm^3/cm^3
n: number of observations summarised, max is 24

**Gapfilled_VWC_temp_wm_daily_place.rds** - same logger data as in **VWC_temp_wm_daily.rds** but averaged across “twin sites”  to overcome missing data so that instead of 8 sites there are 4 places. Due to persistent missing data, one treatment and moss combination (warming and Sphagnum) in one place (Palno) data set has been gap-filled for half the season by assuming a linear relationship between warming and control plots.

## Code/Software

R version 4.3.3 (2024-02-29) was used. Following files call necessary libraries and load uploaded data to reproduce graphs and tables for associated paper, incl. supporting information.

**Stats_Figs.R** – calls the .rds files to reproduce all figures and statistics in the main paper and supplementary files (except Figure S1 (Map with site positions) and S2 (uses publically available data from the Swedish Meteorological and Hydrological Institute).

**GAMM_by_moss_precip_otc.R** – Runs generalized additive models and predicts moss species-specific N2 fixation based on model parameters and microclimate data measured in plots.
